#
# spec file for package timoni
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           timoni
Version:        0.20.0
Release:        1.2
Summary:        Package manager for Kubernetes, powered by CUE and inspired by Helm
License:        Apache-2.0
URL:            https://github.com/stefanprodan/timoni
Source:         timoni-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
Timoni is a package manager for Kubernetes, powered by CUE and inspired by Helm.

The Timoni project strives to improve the UX of authoring Kubernetes configs. Instead of mingling Go templates with YAML like Helm, or layering YAML on top of each-other like Kustomize, Timoni relies on cuelang's type safety, code generation and data validation features to offer a better experience of creating, packaging and delivering apps to Kubernetes.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%setup -q
%setup -q -T -D -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X main.VERSION=%{version}" \
   -o bin/timoni ./cmd/timoni

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Sun Mar 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.20.0:
  * Update website copyright year
  * Adjust copyright year
  * Add docs for referencing local modules in bundles
  * Update Redis module to v7.2.4
  * Document the flux-oci-sync usage
  * Allow runtime definition to be coupled with a bundle
  * Add tests for bundles with local modules
  * Add scoop.sh instructions to install.md
  * build(deps): bump the ci group with 1 update
  * chore: cleanup unused function
  * chore: restore example
  * docs: add bundle file module url
  * feat: add generic new fetcher
  * Correct reference to "timoni.sh/core/v1alpha1".#ObjectReference
  * test: add oci fetcher test
  * test: add local fetcher test
  * chore: switch redis module to relative
  * feat: add support for file module in bundle
  * refactor: move fetcher to its own dedicated package
  * feat: add file protocol support in cue constraint
  * Document the Flux AIO upgrade procedure
  * Run e2e tests for Kubernetes v1.29.2
  * Update `fluxcd/pkg/ssa` to v0.36.0
  * Update `cuelang.org/go` to v0.7.1
  * Update controller-gen to v0.14.0
  * Build with Go 1.22
  * Update core CUE schemas
  * Refactor `ImagePullSecret` generator
  * build(deps): bump the ci group with 3 updates
  * docs: add proto documentation
  * chore: add proto plugin
  * Use shorter syntax for string keys
  * test(engine): add module builder case around invalid value
    merging
  * fix(engine): return values merge error if non nil
  * fix(doc): Fix typo on "Push to GitHub Container Registry"
  * doc/fix cue command parameter order
  * Set correct make target name
  * Use `t.TmpDir()` instead of working dir
  * Update copyright year
  * Updated to make use of the convention +nodoc
  * Add test and setup command show and attach config command Test
    reading and writing to the output file
  * Add output flag
  * Initial run at generating a markdown table for the module
    configuration
- BuildRequire go1.22 to follow upstream
* Sun Jan 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.19.0:
  * docs: Format Get Started guide
  * docs: Add immutable ConfigMaps and Secrets guide
  * Add `#ImmutableConfig` generator to CUE schemas
  * Fix typo
  * build(deps): bump the ci group with 1 update
  * Add Cosign keyless verification example (#316)
  * Persist module OCI annotations in the in-cluster instance
  * docs: Add module instance to spec
  * docs: Add redirects to module section
  * docs: Add module spec
  * docs: Updates the links to module pages
  * docs: How to update the Timoni schemas
  * Bump the ci group with 1 update
  * set defaultPath as an empty string
  * find the correct kubeconfig based on thee current context
  * docs: specifies where the instance inventory is stored
  * docs: Rename `_config` to `#config`
  * docs: Add Import Resources from YAML guide
  * docs: Add Module Distribution with GitHub Actions guide
  * docs: Add Module Signing and Verification guide
  * docs: Add Module Publishing guide
  * docs: Add Run tests with Jobs guide
  * docs: Add Control the Apply Behaviour guide
  * docs: Add Cluster Version Constraints guide
  * docs: Add Custom Resources guide
  * docs: Add module development get started guide
  * docs: Add CUE Features Walkthrough
  * docs: Add CUE reference section
  * Enable GitHub Sponsors
  * ci: Push blueprints on-demand
  * Refactor example module with nested packages
  * Change the `config` type to definition
  * docs: Format code blocks with CUE v0.7.0
* Thu Jan  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.18.0:
  * Add `#ObjectReference` to Timoni's CUE schemas
  * feat: add values argument to vet command
  * Add `--blueprint` arg to `timoni mod init` cmd
  * Mark cue.mod as vendored
  * Allow connecting to insecure container registries
  * Exclude blueprints
  * Publish starter blueprint to GHCR
  * Bump golang.org/x/crypto from 0.16.0 to 0.17.0
  * Vet and format blueprints
  * Add starter blueprint
  * Bump the ci group with 1 update
  * Document managed-by label usage
  * Init blueprint
  * Document the Timoni's CUE schemas
  * Refactor redis module using latest schemas
  * Refactor init module using latest schemas
  * Update cue version info
  * Add `timoni artifact tag` command
  * Compose `#LabelSelector` in `#Metadata`
  * Add `#MetaComponent` generator to Timoni's CUE schemas
  * Add `--name` flag to `timoni mod vet` command (#272)
  * Workaround for preserve-unknown-fields arrays issue For CRDs
    with arrays the `parentPath` function doesn't walk back to the
    spec. To not miss `x-kubernetes-preserve-unknown-fields` we do
    partial matching which could open more fields than desired if
    the field names overlap.
  * Prove that preserve-unknown-fields doesn't work with arrays If
    an array type is present in the CRD, the `parentPath` function
    fails to compose the full path to the spec parent for all
    fields declared after the array.
  * Format with cue v0.7.0
  * Update `cuelang.org/go` to v0.7.0
  * Bump the ci group with 2 updates
  * Add image pull secret generator to Timoni's CUE schemas
  * Fix label selector schema
  * Run `cue vet` for schemas in CI
  * Add semver validation to Timoni's CUE schemas
  * Add resource requirements to Timoni's CUE schemas
  * Add instance definitions to Timoni's CUE schemas
  * Run `cue fmt` in CI
  * Add managed-by to default labels
  * Add standard Kubernetes labels to metadata
  * Document the module config required fields
  * Improve cmd test coverage
* Wed Nov 29 2023 kastl@b1-systems.de
- Update to version 0.17.0:
  * Add Helm interoperability to docs
  * Add Flux AIO distribution to docs
  * Add note about using Timoni with Flux
  * Bump the ci group with 1 update
  * Improve multi-cluster intro
  * Improve error handling
  * Update example modules - Bump nginx to 1.25.3 - Bump redis to
    7.2.2
  * Add multi-cluster deployments guide to docs
  * Add `clusters` spec to Runtime API docs
  * Make runtime values optional
  * Add cluster group to instance logs
  * Enforce cluster selection for `bundle build` cmd
  * Add multi-cluster support to `bundle delete` cmd
  * Add multi-cluster support to `bundle status` cmd
  * Add multi-cluster support to `bundle apply` cmd
  * Add default cluster to API
  * Add multi-cluster support to `bundle vet` cmd
  * Add cluster info runtime values to API
  * Add bundle global runtime args
  * Add cluster aware logger
  * Add cluster selector to runtime cmd
  * Add runtime cluster selector to API
  * Add test for runtime build with clusters
  * Add runtime clusters to API
  * Setup local cluster fleet
  * Add clusters to Runtime API
  * Update dependencies to Kubernetes v1.28
  * Add mkdoc setup to CONTRIBUTING.md
  * Correct small mistakes throughout the docs
  * Tidy up the mod init command
  * Tidy up the bundle commands
  * Create output dir instead of returning error for OCI artifacts
    (#246)
  * Handle immutable resources at dry-run
  * Bump the ci group with 1 update
* Mon Nov 13 2023 kastl@b1-systems.de
- Update to version 0.16.0:
  * Add local cache to install docs
  * Add install docs for Arch Linux and openSUSE
  * Update dependencies
  * docs: update secret doc to use FIFO instead of temporary file
  * Use direct cluster reader for health checks Reduce memory usage
    when waiting for resources to become ready.
  * Enable caching for modules - Add `--cache-dir` flag with
    default location set to `$HOME/.timoni/cache` - Allow disabling
    caching with `TIMONI_CACHING=false` env var
  * Implement caching for module's OCI layers
  * Bump Redis to 7.2.2-r2
  * Bump podinfo to 6.5.3
  * Bump github.com/docker/docker
  * Add node affinity to examples
  * Add test for bundle vetting computed value
  * Introduce `timoni bundle vet` command
* Mon Oct 30 2023 kastl@b1-systems.de
- Update to version 0.15.0:
  * Document how to inject secrets at apply-time
  * Add social card to website
  * Add feature list to readme
  * Design the homepage of Timoni's website
  * Link to concepts page
  * Hide toc on CLI docs
  * Add concepts page to docs
  * test: add metadata name and namespace test
  * fix(importer): fix nil pointer on crd with no spec
  * test(importer): add empty spec test
  * Bump the ci group with 1 update
  * Add Timoni logo
  * Push clean schemas to GHCR
  * Refactor action schema
  * Bump Redis to 7.2.2
  * ci: Fix schemas push
  * Document how to update the CUE schemas
  * Publish Timoni's CUE schemas to GHCR
  * Report images without digests
  * Add tests for container image listing
  * List container images referenced by an instance
  * Add container image refs to instance storage
  * Extract container image refs at build-time
  * Add container image refs to instance metadata
  * Add vet command to docs
  * Add vet command for modules and debug values
  * engine: Vet module instance at build-time
  * engine: Verify required module files
  * docs: Running tests with Kubernetes Jobs
  * Run connectivity test in CI
  * Add connectivity test example
  * Add connectivity test to Redis module
  * Add actions to Timoni's core schemas
  * runtime: Wait for Kubernetes Jobs completion
  * Migrate the instance storage from the Opaque type
  * Add `timoni bundle status` to docs
  * Add tests for bundle status
  * Add `timoni bundle status` command List the current status of
    the managed resources for each instance including the last
    applied date, the module url and digest.
  * Add tests for instance status
  * Bump podinfo to 6.5.2
  * Refactor Redis module
  * Bump golang.org/x/net from 0.14.0 to 0.17.0
  * Use tabular view for `timoni inspect resources` Print resources
    managed by an instance in a tabular view with name, namespace
    and API version columns.
  * Set storage secret type to `timoni.sh/instance`
  * Persist values for reproducible instances
  * Refactor bundle delete command Simplify the delete command to
    `timoni bundle delete <name>` and deprecate `--name`. When
    deleting a bundle by referring to a file with `timoni bundle
    delete -f bundle.cue`, the name is extracted from the file
    without parsing the instances or any other fields.
* Sun Oct  8 2023 kastl@b1-systems.de
- Update to version 0.14.2:
  * Log bundle apply duration
  * Print artifact URL and digest after push
  * bundle: Pull all modules before attempting apply
  * Uninstall bundle instances in reverse order
* Sat Oct  7 2023 kastl@b1-systems.de
- Update to version 0.14.1:
  * Update dependencies - github.com/fluxcd/pkg/ssa v0.32.1 -
    github.com/fluxcd/pkg/tar v0.3.0 - github.com/otiai10/copy
    v1.14.0
  * Set dark mode pallet
* Mon Oct  2 2023 kastl@b1-systems.de
- Update to version 0.14.0:
  * Enable dark mode for docs website
  * Remove `--source` flag from `timoni mod push` The source
    annotation is now set automatically from Git metadata. The
    source can also be explicitly set using `timoni mod push
  - -annotation='org.opencontainers.image.source=<URL>`.
  * Document artifact media types and annotations
  * Consolidate artifact annotations
  - Use the OCI version annotation for modules
  - Set the source, revision and created annotation from Git
    metadata
  - Rename `--annotations` to `--annotation` arg in `timoni mod
    push`
  - Allow overriding the source and revision values with the
    `--annotation` flags
  * Document bundle distribution
  * Add artifact commands to docs index
  * Add `artifact list` command
  * Add `ArtifactReference` to API
  * Store the module's schemas is dedicated layer
  * Test artifacts operations
  * Refactor artifacts operations
  * Add registry login/logout to docs
  * Add registry login/logout commands
  * Refactor artifacts operations
  * Push Timoni schemas to GCHR
  * Add cmd for pulling generic artifacts
  * Add cmd for pushing generic artifacts
  * Add debug values to init module
  * Document Kubernetes APIs and CRDs vendoring
  * Bump the ci group with 1 update
  * Vendor Kubernetes GA APIs into minimal
  * Update the docs with the core schemas
  * Push schemas to `ghcr.io/stefanprodan/timoni/schemas`
  * Use `timoni.sh/core/v1alpha1` schemas in minimal
  * Introduce Timoni's core schemas
  - `#Image` defines the schema for an OCI image reference.
  - `#Metadata` defines the schema for the Kubernetes object
    metadata.
  - `#Selector` defines the schema for Kubernetes pod label
    selector used in Deployments, Services, Jobs, etc.
  * Add commands for vendoring CUE schemas - `timoni mod vendor
    k8s` - `timoni mod vendor crds -f`
  * Refactor examples
  - Move podinfo module to
    https://github.com/stefanprodan/podinfo/tree/master/timoni/podinfo
  - Update Redis module to v7.2.1
  - Update Minimal module to nginx v1.25.2
  - Update docs to point to the new example modules versions
  * Add cmd for importing Kubernetes API schemas
  * Add spinner to mod import crd
  * Fetch CRDs over HTTPS
  * Extract CRDs from multi-doc YAMLs This allows importing CRDs
    from multi-doc YAML files that contain other Kubernetes
    resources besides just CRDs.
  * engine: Refactor the CRD importer Add a top level function for
    converting multi-doc YAML files to CUE definition. The function
    returns key value pairs, contain a unique identifier in the
    format `<group>/<kind>/<version>` and the contents of the CUE
    definition.
  * Bump the ci group with 2 updates
  * Add tests for `mod import crd`
  * Implement Kubernetes CRD import command
  * engine: Remove status from CRD cue gen
  * Bump the ci group with 2 updates
  * docs: Add the Runtime API to comparison doc
  * bundle: Fix values merge with module defaults
* Mon Sep 11 2023 kastl@b1-systems.de
- Update to version 0.13.1:
  * bundle: Fix values merge with module defaults
* Mon Sep 11 2023 kastl@b1-systems.de
- Update to version 0.13.0:
  * docs: Add Nix installation instructions
  * ci: Push and sign minimal module Publish signed (cosign
    keyless) module to `oci://ghcr.io/stefanprodan/timoni/minimal`
  * docs: Signing modules with Cosign - add signing with Cosign
    static keys and keyless to module publishing docs - add Cosign
    Keyless example to the GitHub Actions docs
  * Add cosign signing and verification for modules (#182)
  * Enforce Kubernetes min version for modules
  * Use Go 1.21 stdlib
  * Add tests for the runtime flag
  * Add the runtime flag to bundle cmd
  * Decode Secret data from base64
  * Add bundle runtime documentation
  * Replace `@timoni(env)` with `@timoni(runtime)` Make reading env
    vars an opt-in feature `timoni bundle --runtime-from-env`
  * Introduce the Runtime API
  * Prefix Kubernetes flags Add `kube-` prefix to all the flags
    specific to Kubernetes to avoid collision with OCI registry.
  * Add a YAML CRD to CUE IR conversion function
  * Bump github.com/cyphar/filepath-securejoin from 0.2.3 to 0.2.4
* Tue Sep  5 2023 kastl@b1-systems.de
- Update to version 0.12.1:
  * Fix panic when waiting for global resources
* Tue Sep  5 2023 kastl@b1-systems.de
- Update to version 0.12.0:
  * Update example modules
  - podinfo v6.4.1
  - redis v7.2.0
  - minimal v0.1.0
  * Mark image fields as required Use CUE 0.6 required fields
    feature for better error messages when required fields are
    missing from values.
  * Build with Go 1.21
  * Bump the ci group with 2 updates
  * Run server-side apply operations in parallel Speed up the
    Kubernetes resources reconciliation by running the server-side
    apply operations in parallel.
  * Set standard Kubernetes labels: app name and version
  * Use metadata abstraction in the module template
  * Introduce Kubernetes metadata CUE definition
  * Inject version info Add optional tags to inject the module
    version and Kubernetes version at runtime.
  * Update `cuelang.org/go` to v0.6.0
  * Bump the ci group with 3 updates
  * Document how to change the apply behaviour
  * Add support for one-off resources To apply resources only if
    they don't exist on the cluster, module authors can annotate
    them with `action.timoni.sh/one-off: "enabled"`.
  * Update dependencies
  * Bump the ci group with 2 updates
* Tue Aug  1 2023 kastl@b1-systems.de
- Update to version 0.11.1:
  * Fail fast when waiting for resources
  * Update dependencies
  - k8s.io/* v0.27.4
  - github.com/fluxcd/pkg/oci v0.30.0
  - github.com/fluxcd/pkg/ssa v0.29.0
  - github.com/homeport/dyff v1.5.8
  - github.com/rs/zerolog v1.30.0
* Mon Jul 24 2023 kastl@b1-systems.de
- Update to version 0.11.0:
  * test: add get instance case
  * test: add quoted instance test
  * fix: unquote instance name
  * Update the module structure doc to match minimal
  * Publish init module to `ghcr.io/stefanprodan/timoni/minimal`
  * Add healthz endpoint
  * Use minimal module for `timoni mod init`
  * Add minimal module example
  * Update Redis to 7.0.12 and use image digest
  * Add local dev setup
  * Fix bundle build test flake Reset flags to avoid test failures
    of `timoni bundle build`
  * Bump the ci group with 2 updates
  * Colorize bundle lint
  * Colorize status
  * Added missing 'return if err' check
  * Added coloring to inspect resources
  * Changed to use color.Output & color.Error
  * Refactored colorize
  * Prettier and more colorized output
  * Added completion on installed instances & --namespace
  * Add stale resources to the dry run output
* Sat Jul  8 2023 kastl@b1-systems.de
- Update to version 0.10.0:
  * ci: Pin cuelang version to v0.5.0
  * ci: Enable dependabot grouping
  * Normalise the SLSA provenance files
  * Document how to build bundles from JSON/YAML
  * test: add bundle files test
  * feat: add json support
  * feat: add yaml support for bundles
  * Bump anchore/sbom-action from 0.14.2 to 0.14.3
* Fri Jun 23 2023 kastl@b1-systems.de
- Update to version 0.9.0:
  * Enabled reproducible builds of OCI artifacts Use the source
    date epoch (recommend by reproducible-builds.org) to set the
    OCI artifact created timestamp. The source date is extracted
    from Git metadata and requires the `git` CLI to be in PATH.
    This ensures that `timoni mod push` will generate an artifact
    with the same digest, if run multiple times on the same checked
    out commit.
  * Update dependencies
  * Add support for env var injection in bundles
  * Bump goreleaser/goreleaser-action from 4.2.0 to 4.3.0
  * Bump slsa-framework/slsa-github-generator from 1.6.0 to 1.7.0
  * Bump actions/checkout from 3.5.2 to 3.5.3
  * Bump github/codeql-action from 2.3.6 to 2.13.4
  * Bump github/codeql-action from 2.3.5 to 2.3.6
  * Add env injector to CUE engine
  * docs: Normalise page titles
  * Add Helm comparison to docs
* Mon May 29 2023 kastl@b1-systems.de
- Update to version 0.8.2:
  * Merge the bundle values with the module defaults
* Mon May 29 2023 kastl@b1-systems.de
- Update to version 0.8.1:
  * Add CUE version to `timoni version` output
  * Map the timeout flag to apply wait operations
  * Bump github/codeql-action from 2.3.3 to 2.3.5
* Mon May 29 2023 kastl@b1-systems.de
- Update to version 0.8.0:
  * Increase default timeout to 5m
  * Add spinner to long-running operations
  * Pass logger via command context
  * Add pretty print for logs and diff output
  * Update dependencies to Kubernetes 1.27
  * update cue to v0.5.0
  * Bump helm/kind-action from 1.5.0 to 1.7.0
  * Bump actions/setup-go from 4.0.0 to 4.0.1
  * Document SLSA Provenance & SBOMs
* Tue May 16 2023 kastl@b1-systems.de
- Update to version 0.7.1:
  * Generate SLSA3+ Provenance
* Tue May 16 2023 kastl@b1-systems.de
- Update to version 0.7.0:
  * Add security policy Explain how to report a vulnerability and
    how we handle vulnerability disclosures for the Timoni project.
  * test: bundle build cmd
  * docs: bundle build cmd
  * feat: add bundle build command
  * Bump github.com/docker/distribution
* Thu May 11 2023 kastl@b1-systems.de
- Update to version 0.6.0:
  * Fix apply dry-run for new namespaces
  * Add `timoni.ignore` to module documentation
  * Add support for `timoni.ignore` - Allow defining ignore patters
    with `timoni.ignore` (same format as `.gitignore`) - Add a
    default ignore file to `timoni mod init` - Exclude ignored
    files and directories when pushing modules to registry - Load
    `timoni.ignore` when performing operations with local modules
  * Bump anchore/sbom-action from 0.14.1 to 0.14.2
  * Bump github/codeql-action from 2.3.2 to 2.3.3
* Thu May  4 2023 kastl@b1-systems.de
- Update to version 0.5.0:
  * Update example modules and bundles
  - bump podinfo to 6.3.6
  - bump redis to 7.0.11
  * Target all namespaces when deleting a named bundle
  * Implement native linting
  * Enforce instance schema validation
  * Add instance schema to API
  * Enable name-oriented bundle management
  * Bump github/codeql-action from 2.2.12 to 2.3.2
  * Ensure all CUE build errors are printed
  * Improve how `GetResource` works
  * Bump github/codeql-action from 2.2.11 to 2.2.12
  * Bump actions/checkout from 3.5.0 to 3.5.2
  * Add force upgrade option to bundle docs
  * Add a bundle example to quickstart
  * Correct target of mod push doc link
* Thu Apr 13 2023 kastl@b1-systems.de
- Update to version 0.4.0:
  * Document how bundles work
  * Implement delete command for bundles
  * Add bundle test for digest and latest version
  * Add bundle tests for module digest
  * Refactor bundle apply
  - use BundleBuilder to validate and extract instances
  - allow pinning a module by its OCI digest
  - pull latest module when the version and digest are not
    specified
  - when both the module version and the digest are specified,
    error out if the OCI digest of the version doesn't match the
    specified digest
  * Use the bundle builder for linting
  * Add bundle builder to engine The BundleBuilder compiles CUE
    definitions to Go Bundle objects, and extracts and validates
    instances.
  * Fetch module by OCI digest
  * Add digest optional field to Bundle API
  * Implement listing command for module versions The `timoni mod
    list oci://<module-url>` command prints a table with a module's
    versions and their OCI digests.
  * Bump github/codeql-action from 2.2.9 to 2.2.11
  * Add Arkade install method
  * Add image digest to examples
  * Bump redis to 7.0.10
  * Bump podinfo to 6.3.5
  * Document module publishing and versioning
  * Bump github.com/docker/docker
* Thu Apr  6 2023 Johannes Kastl <kastl@b1-systems.de>
- new package timoni: package manager for Kubernetes, powered by
  CUE and inspired by Helm
